@@ -30,13 +30,10 @@
 #ifndef EPOXY_WGL_H
 #define EPOXY_WGL_H
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#include <stdbool.h>
 #include <windows.h>
 
+#include "epoxy/common.h"
+
 #undef wglUseFontBitmaps
 #undef wglUseFontOutlines
 
@@ -54,11 +51,11 @@ extern "C" {
 
 #include "epoxy/wgl_generated.h"
 
-bool epoxy_has_wgl_extension(HDC hdc, const char *extension);
-void epoxy_handle_external_wglMakeCurrent(void);
+EPOXY_BEGIN_DECLS
 
-#ifdef __cplusplus
-} /* extern "C" */
-#endif
+EPOXY_PUBLIC bool epoxy_has_wgl_extension(HDC hdc, const char *extension);
+EPOXY_PUBLIC void epoxy_handle_external_wglMakeCurrent(void);
+
+EPOXY_END_DECLS
 
 #endif /* EPOXY_WGL_H */
