@@ -27,7 +27,7 @@
 
 #include "dispatch_common.h"
 
-PUBLIC int
+int
 epoxy_conservative_egl_version(void)
 {
     EGLDisplay dpy = eglGetCurrentDisplay();
@@ -38,7 +38,26 @@ epoxy_conservative_egl_version(void)
     return epoxy_egl_version(dpy);
 }
 
-PUBLIC int
+/**
+ * @brief Returns the version of OpenGL we are using
+ *
+ * The version is encoded as:
+ *
+ * ```
+ *
+ *   version = major * 10 + minor
+ *
+ * ```
+ *
+ * So it can be easily used for version comparisons.
+ *
+ * @param The EGL display
+ *
+ * @return The encoded version of EGL we are using
+ *
+ * @see epoxy_gl_version()
+ */
+int
 epoxy_egl_version(EGLDisplay dpy)
 {
     int major, minor;
@@ -54,16 +73,45 @@ epoxy_egl_version(EGLDisplay dpy)
 bool
 epoxy_conservative_has_egl_extension(const char *ext)
 {
-    EGLDisplay dpy = eglGetCurrentDisplay();
-
-    if (!dpy)
-        return true;
-
-    return epoxy_has_egl_extension(dpy, ext);
+    return epoxy_has_egl_extension(eglGetCurrentDisplay(), ext);
 }
 
-PUBLIC bool
+/**
+ * @brief Returns true if the given EGL extension is supported in the current context.
+ *
+ * @param dpy The EGL display
+ * @param extension The name of the EGL extension
+ *
+ * @return `true` if the extension is available
+ *
+ * @see epoxy_has_gl_extension()
+ * @see epoxy_has_glx_extension()
+ */
+bool
 epoxy_has_egl_extension(EGLDisplay dpy, const char *ext)
 {
-    return epoxy_extension_in_string(eglQueryString(dpy, EGL_EXTENSIONS), ext);
+    return epoxy_extension_in_string(eglQueryString(dpy, EGL_EXTENSIONS), ext) || epoxy_extension_in_string(eglQueryString(NULL, EGL_EXTENSIONS), ext);
+}
+
+/**
+ * @brief Checks whether EGL is available.
+ *
+ * @return `true` if EGL is available
+ *
+ * @newin{1,4}
+ */
+bool
+epoxy_has_egl(void)
+{
+#if !PLATFORM_HAS_EGL
+    return false;
+#else
+    EGLDisplay* (* pf_eglGetCurrentDisplay) (void);
+
+    pf_eglGetCurrentDisplay = epoxy_conservative_egl_dlsym("eglGetCurrentDisplay", false);
+    if (pf_eglGetCurrentDisplay)
+        return true;
+
+    return false;
+#endif /* PLATFORM_HAS_EGL */
 }
